One true-versus-estimated panel per parameter type, with the identity line and the correlation and RMSE.
Examples
# \donttest{
d <- simulate_rasch(300, 8, seed = 1)
fit <- rasch(d, id = "id")
plot_recovery(sim_recovery(fit, d))
# }
One true-versus-estimated panel per parameter type, with the identity line and the correlation and RMSE.
# \donttest{
d <- simulate_rasch(300, 8, seed = 1)
fit <- rasch(d, id = "id")
plot_recovery(sim_recovery(fit, d))
# }