Caterpillar plot of the object locations with 95 per cent error bars, misfitting objects highlighted, in the package's house style.
Arguments
- fit
An object from
btl.- band
Absolute fit-residual value beyond which an object is highlighted.
Caterpillar plot of the object locations with 95 per cent error bars, misfitting objects highlighted, in the package's house style.
An object from btl.
Absolute fit-residual value beyond which an object is highlighted.