Person locations against person fit residuals with the +/- 2.5 band; persons beyond the band respond erratically (positive) or too deterministically (negative).
Arguments
- fit
A fitted object from
rasch.- band
Fit residual acceptance band.
Person locations against person fit residuals with the +/- 2.5 band; persons beyond the band respond erratically (positive) or too deterministically (negative).
A fitted object from rasch.
Fit residual acceptance band.