Builds the index mapping each item-category threshold to a global id, given the maximum score of each item.
Examples
threshold_index(c(1, 3, 2))
#> id item k
#> 1 1 1 1
#> 2 2 2 1
#> 3 3 2 2
#> 4 4 2 3
#> 5 5 3 1
#> 6 6 3 2
Builds the index mapping each item-category threshold to a global id, given the maximum score of each item.
threshold_index(c(1, 3, 2))
#> id item k
#> 1 1 1 1
#> 2 2 2 1
#> 3 3 2 2
#> 4 4 2 3
#> 5 5 3 1
#> 6 6 3 2